# frozen_string_literal: true
SSL_ENVS = %w(production staging)

Application.boot(:cache, namespace: true) do
  init do
    require 'aws_account_status/clients/redis'
    require 'aws_account_status/clients/region_service_support_redis'
  end

  start do
    redis_host = target[:settings].redis_host
    redis_port = target[:settings].redis_port

    # rediss:// is not a typo.
    # Enables SSL connection within `redis` gem.
    redis_uri_scheme = SSL_ENVS.include?(ENV['RACK_ENV']) ? 'rediss://' : 'redis://'
    redis_url = "#{redis_uri_scheme}#{redis_host}:#{redis_port}"

    log = target[:settings].redis_debug == 1 ? target[:logger] : nil

    redis_options = {
      url: redis_url,
      logger: log,
      auto_reconnect: true
    }

    cache_redis = ::AwsAccountStatus::Clients::Redis.new(nil, redis_options)
    register(:redis, cache_redis)

    region_service_support_redis = ::AwsAccountStatus::Clients::RegionServiceSupportRedis.new(nil, redis_options)
    register(:region_service_support_redis, region_service_support_redis)
  end
end
