# frozen_string_literal: true

# Starts the DynamoDB client.
# Always uses default SDK authentication, but takes endpoint and region from config, if provided.
Application.boot(:dynamodb, namespace: true) do
  init do
    require 'aws-sdk-dynamodb'
  end

  start do
    endpoint   = target[:settings].dynamodb_url
    region     = target[:settings].dynamodb_region
    table_name = target[:settings].dynamodb_account_region_status_table_name

    config               = {}
    config[:region]      = region unless region.nil?
    config[:endpoint]    = endpoint unless endpoint.nil?

    # Only include the credential settings if the settings allow it. This is used in all NG environments.
    # When running the service locally without the setting set, the AWS class will fallback to using whatever
    # is available in the environment using default resolution rules.
    #
    # NOTE:  This method is not supported in the new EKS environment, so this is set to "0" there, and this
    #        code can be removed once we're fully migrated to EKS.
    if target[:settings].use_creds_from_instance_metadata == 1
      config[:credentials] = ::Aws::InstanceProfileCredentials.new # Using defaults
    end

    # Trust that the AWS SDK is thread-safe and use a single client for all calls, just like we share a Redis
    # client across all calls/threads.
    dynamo_db_client = ::Aws::DynamoDB::Client.new(config)
    register('client', dynamo_db_client)

    # `call: false` makes this a Proc, which will be run each time it's resolved
    register('account_region_status_table', call: false) do
      ::Aws::DynamoDB::Table.new(table_name, client: dynamo_db_client)
    end
  end
end
